diff -Nur snes9x-org/makefile snes9x-sdljoy/makefile
--- snes9x-org/makefile	2003-10-28 16:49:50.000000000 +0900
+++ snes9x-sdljoy/makefile	2005-05-11 21:58:09.000000000 +0900
@@ -78,13 +78,13 @@
 OPENGLNO_DEPENDS=use_opengl
 endif
 
-CCC = gcc
-CC = gcc
+CCC = arm-linux-gcc
+CC = arm-linux-gcc
 NASM = nasm
 
-INCLUDES=-I/usr/local/include
+INCLUDES=-I/opt/zaurus/include
 
-OPTIMISE= -D_ZAURUS -Os -ffast-math -fstrict-aliasing -fomit-frame-pointer -mcpu=strongarm1100 -mtune=strongarm1100
+OPTIMISE= -D_ZAURUS -O2 -fstrict-aliasing -fomit-frame-pointer -mcpu=xscale -mtune=xscale 
 CCFLAGS = $(OPTIMISE) \
 -I/opt/Qtopia/include/SDL \
 -I. \
@@ -146,7 +146,8 @@
 	$(RM) $(OPENGLNO_DEPENDS)
 
 snes9x: $(OBJECTS) 
-	$(CCC) $(INCLUDES) -o $@ $(OBJECTS) $(EXTRALIBS) -L/opt/QtPalmtop/lib/ -lSDL -lSDLmain $(LDLIBS) -lqpe -lqte -lpthread
+	$(CCC) $(INCLUDES) -o $@ $(OBJECTS) $(EXTRALIBS) -L/opt/QtPalmtop/sharp/lib/ -lSDL -lSDLmain $(LDLIBS) -lqpe -lqte -lpthread libstdc++.a
+	arm-linux-strip snes9x
 
 gsnes9x: $(OBJECTS) unix/x11.o unix/glide.o
 	$(CCC) $(INCLUDES) -o $@ $(OBJECTS) unix/x11.o unix/glide.o $(LDLIBS) $(GLIDELIBS) -lXext -lX11 -lXxf86dga -lXxf86vm $(EXTRALIBS) -lz -lm
diff -Nur snes9x-org/unix/svga.cpp snes9x-sdljoy/unix/svga.cpp
--- snes9x-org/unix/svga.cpp	2003-10-28 10:08:18.000000000 +0900
+++ snes9x-sdljoy/unix/svga.cpp	2005-06-11 21:21:04.000000000 +0900
@@ -62,9 +62,12 @@
 
 #define COUNT(a) (sizeof(a) / sizeof(a[0]))
 
+#define SDL_DIRECT	0x04000000	/* Direct Update flag */
+
 SDL_Surface *screen, *gfxscreen;
 uint16 *RGBconvert;
 extern uint32 xs, ys, cl, cs;
+extern bool8_32 rotation, direct, doublebuf;
 
 #ifndef _ZAURUS
 int S9xMinCommandLineArgs ()
@@ -84,6 +87,14 @@
 extern uint8 *keyssnes;
 void S9xInitDisplay (int /*argc*/, char ** /*argv*/)
 {
+  int flags = SDL_HWSURFACE|SDL_FULLSCREEN;
+;
+  if(direct)
+    flags |= SDL_DIRECT;
+ 
+  if(doublebuf)
+    flags |= SDL_DOUBLEBUF;
+
 	if (SDL_Init(SDL_INIT_VIDEO | (Settings.NextAPUEnabled ? SDL_INIT_AUDIO : 0)) < 0 ) 
 	{
 		printf("Could not initialize SDL(%s)\n", SDL_GetError());
@@ -91,7 +102,7 @@
 	}
 	atexit(SDL_Quit);
 	keyssnes = SDL_GetKeyState(NULL);
-	screen = SDL_SetVideoMode(xs, ys, 16, SDL_HWSURFACE|SDL_DOUBLEBUF|SDL_FULLSCREEN);
+	screen = SDL_SetVideoMode(xs, ys, 16, flags);
 	if (screen == NULL)
 	{
 		printf("Couldn't set video mode: %s\n", SDL_GetError());
diff -Nur snes9x-org/unix/unix.cpp snes9x-sdljoy/unix/unix.cpp
--- snes9x-org/unix/unix.cpp	2003-10-28 22:09:02.000000000 +0900
+++ snes9x-sdljoy/unix/unix.cpp	2005-06-11 21:21:43.000000000 +0900
@@ -93,10 +93,10 @@
 extern void S9xDisplayString (const char *string, uint8 *, uint32);
 extern SDL_Surface *screen;
 
-static uint32 ffc = 0;
-bool8_32 nso = FALSE, vga = FALSE;
+static uint32 ffc = 0; 
+bool8_32 nso = FALSE, vga = FALSE, joystick = FALSE;
+bool8_32 direct = FALSE, rotation = FALSE, doublebuf = TRUE;
 uint32 xs = 320, ys = 240, cl = 0, cs = 0, mfs = 10;
- 
 
 char *rom_filename = NULL;
 char *snapshot_filename = NULL;
@@ -124,6 +124,193 @@
     exit (1);
 }
 
+
+/************************************************************ 
+   joystick support
+*************************************************************/
+static Uint16 joymap[16];
+
+typedef struct {
+  SDL_Joystick* joy;
+  int commit_range;
+  int xstatus, ystatus;
+  int number;
+} t_sdl_joystick;
+
+static t_sdl_joystick sdl_joystick;
+
+/* These can be used for 'input.pad[]' */
+#define UP          (0x0)
+#define DOWN        (0x1)
+#define LEFT        (0x2)
+#define RIGHT       (0x3)
+#define BUTTON1     (0x4)
+#define BUTTON2     (0x5)
+#define BUTTON3     (0x6)
+#define BUTTON4     (0x7)
+#define BUTTON5     (0x8)
+#define BUTTON6     (0x9)
+#define START       (0xa)    
+#define SELECT      (0xb)
+
+static int joystick_init()
+{
+  FILE *fd;
+  char str[256];
+  int i;
+
+  if(SDL_InitSubSystem(SDL_INIT_JOYSTICK) < 0) {
+    printf("ERROR: %s.\n", SDL_GetError());
+    return 0;
+  }
+  else {
+    sdl_joystick.commit_range = 3276;
+    sdl_joystick.xstatus = 1;
+    sdl_joystick.ystatus = 1;
+    sdl_joystick.number = 0;
+
+    if ( (fd = fopen(".snes9x", "r")) == NULL)
+      fd = fopen("/home/zaurus/Settings/.snes9x", "r");
+
+    if(fd == NULL){
+      printf("\nUsing standard joystick setting.\n");
+      joymap[UP] = SDLK_UP;
+      joymap[DOWN] = SDLK_DOWN;
+      joymap[LEFT] = SDLK_LEFT;
+      joymap[RIGHT] = SDLK_RIGHT;
+      joymap[BUTTON1] = SDLK_d;
+      joymap[BUTTON2] = SDLK_c;
+      joymap[BUTTON3] = SDLK_s;
+      joymap[BUTTON4] = SDLK_x;
+      joymap[BUTTON5] = SDLK_a;
+      joymap[BUTTON6] = SDLK_z;
+      joymap[START] = SDLK_RETURN;
+      joymap[SELECT] = SDLK_SPACE;
+    }else{
+      printf("\nReading .snes9x.\n");
+      i = 0;
+      while( (fgets(str, 255, fd) != NULL) && (i < 16)){
+	joymap[i] = strtoul(str, NULL, 16);
+	i++;
+      }
+      fclose(fd);
+    }
+    /*
+    for(i = 0; i<16;i++){
+      printf("joypad %d -  keycode = 0x%x\n",i,joymap[i]);
+    }
+    */    
+
+    sdl_joystick.joy = SDL_JoystickOpen(sdl_joystick.number);
+    if(sdl_joystick.joy != NULL) {
+      printf("Joystick (%s) has %d axes and %d buttons.\n", 
+	     SDL_JoystickName(sdl_joystick.number), SDL_JoystickNumAxes(sdl_joystick.joy),
+	     SDL_JoystickNumButtons(sdl_joystick.joy));
+
+      SDL_JoystickEventState(SDL_ENABLE);
+      return 1;
+    }
+    else {
+      printf("ERROR: Could not open joystick: %s.\n", SDL_GetError());
+      return 0;
+    }
+  }
+}
+
+
+static void joystick_update(SDL_Event event)
+{
+	int axisval;
+  switch(event.type) {
+	case SDL_JOYAXISMOTION:
+		switch(event.jaxis.axis) {
+		case 0:	/* X axis */
+			axisval = event.jaxis.value;
+
+			if(axisval > sdl_joystick.commit_range) {
+				if(sdl_joystick.xstatus == 2)
+					break;
+				if(sdl_joystick.xstatus == 0) {
+					keyssnes[joymap[LEFT]] = SDL_RELEASED;
+				}
+				keyssnes[joymap[RIGHT]] = SDL_PRESSED;
+				sdl_joystick.xstatus = 2;
+				break;
+			}
+
+			if(axisval < -sdl_joystick.commit_range) {
+				if(sdl_joystick.xstatus == 0)
+					break;
+				if(sdl_joystick.xstatus == 2) {
+				  keyssnes[joymap[RIGHT]] = SDL_RELEASED;
+				}
+				keyssnes[joymap[LEFT]] = SDL_PRESSED;
+				sdl_joystick.xstatus = 0;
+				break;
+			}
+
+			/* axis is centered */
+			if(sdl_joystick.xstatus == 2) {
+				keyssnes[joymap[RIGHT]] = SDL_RELEASED;
+			}
+			if(sdl_joystick.xstatus == 0) {
+				keyssnes[joymap[LEFT]] = SDL_RELEASED;
+			}
+			sdl_joystick.xstatus = 1;
+			break;
+
+		case 1:	/* Y axis */
+			axisval = event.jaxis.value;
+
+			if(axisval > sdl_joystick.commit_range) {
+				if(sdl_joystick.ystatus == 2)
+					break;
+				if(sdl_joystick.ystatus == 0) {
+					keyssnes[joymap[UP]] = SDL_RELEASED;
+				}
+				keyssnes[joymap[DOWN]] = SDL_PRESSED;
+				sdl_joystick.ystatus = 2;
+				break;
+			}
+			
+      if(axisval < -sdl_joystick.commit_range) {
+				if(sdl_joystick.ystatus == 0)
+					break;
+				if(sdl_joystick.ystatus == 2) {
+					keyssnes[joymap[DOWN]] = SDL_RELEASED;
+				}
+				keyssnes[joymap[UP]] = SDL_PRESSED;
+				sdl_joystick.ystatus = 0;
+				break;
+			}
+
+			/* axis is centered */
+			if(sdl_joystick.ystatus == 2) {
+				keyssnes[joymap[DOWN]] = SDL_RELEASED;
+			}
+			if(sdl_joystick.ystatus == 0) {
+				keyssnes[joymap[UP]] = SDL_RELEASED;			}
+			sdl_joystick.ystatus = 1;
+			break;
+		}
+		break;
+
+	case SDL_JOYBUTTONDOWN:
+	                keyssnes[joymap[(event.jbutton.button+4)]] = SDL_PRESSED;
+		break;
+
+	case SDL_JOYBUTTONUP:
+	                keyssnes[joymap[(event.jbutton.button+4)]] = SDL_RELEASED;
+		break;
+	}
+
+}
+
+/************************************************
+  end of joystick support
+*************************************************/
+
+
 void S9xParseArg (char **argv, int &i, int argc)
 {
 
@@ -148,6 +335,19 @@
 		nso = TRUE;
     else if (strcmp (argv [i], "-x2") == 0)
 		vga = TRUE;
+    else if (strcmp (argv [i], "-d") == 0){
+		direct = TRUE;
+		xs = 480;
+		ys = 640;
+		vga = TRUE;
+		Settings.SupportHiRes = TRUE;
+    }
+    else if (strcmp (argv [i], "-rot") == 0)
+		 rotation = TRUE;
+    else if (strcmp (argv [i], "-nodb") == 0)
+		 doublebuf = FALSE;
+    else if (strcmp (argv [i], "-j") == 0)
+		joystick = TRUE;
     else if (strcmp (argv [i], "-xs") == 0)
     {
 	if (i + 1 < argc)
@@ -228,6 +428,13 @@
     Settings.TurboSkipFrames = 15;
     rom_filename = S9xParseArgs (argv, argc);
 
+//  joystick support
+    if(joystick){
+      printf("Initializing SDL JOYSTICK SUBSYSTEM... ");
+      if(joystick_init())
+	printf("Ok.\n");
+    }
+
 //    Settings.Transparency = Settings.ForceTransparency;
     if (Settings.ForceNoTransparency)
 	Settings.Transparency = FALSE;
@@ -627,7 +834,61 @@
 		lp *= 2;
 
 // 	SDL_LockSurface(screen);
+
 	if (vga) {
+	  if(direct){
+		if ( (Width > 256) && (rotation == FALSE) ) {
+			for (register uint32 i = 0; i < Height; i++) {
+				register uint32 *dp32 = (uint32 *)(screen->pixels) + (i * 480) + 480 * 40;
+				register uint32 *sp32 = (uint32 *)(GFX.Screen) + (i << 8) + 8 ;
+				for (register uint32 j = 0; j < 240; j++)
+					*dp32++ = *sp32++;
+			}
+		} else if ( (Width > 256) && (rotation == TRUE) ) {
+		        for (register uint32 i = 0; i < (Height); i++) {
+				register uint16 *dp16 = (uint16 *)(screen->pixels) + ( 479 - i ) * 2 + 480 * 32*2;
+				register uint16 *sp16 = (uint16 *)(GFX.Screen) + (i << 9) ;
+				for (register uint32 j = 0; j < 512; j++){
+					*dp16 = *sp16++;
+					dp16 += 480;
+				}
+			}
+		} else if( rotation == FALSE ){
+			for (register uint32 i = 0; i < Height*2; i++) {
+			        register uint16 *dp16 = (uint16 *)(screen->pixels) + (i * 480) + 480 * 40 * 2;
+				register uint16 *sp16 = (uint16 *)(GFX.Screen) + ((i>>1) << 9) + 16;
+				for (register uint32 j = 0; j < 240; j++){
+					*dp16++ = *sp16;
+					*dp16++ = *sp16++;
+				}
+			}
+		}else {
+			for (register uint32 i = 0; i < Height; i++) {
+				register uint16 *dp16 = (uint16 *)(screen->pixels) + ( 479 - i) * 2 + 480 * 32 *2 ;
+				register uint16 *sp16 = (uint16 *)(GFX.Screen) + (i << 9);
+				for (register uint32 j = 0; j < 256; j++){
+					*dp16++ = *sp16;
+					*dp16 = *sp16;
+					dp16 += 479;
+					*dp16++ = *sp16;
+					*dp16 = *sp16++;
+					dp16 += 479;
+				}
+			}
+		}
+		if (Settings.DisplayFrameRate)
+		    S9xDisplayFrameRate ((uint8 *)screen->pixels + 100+480*2*150, 1920);
+		if (GFX.InfoString)
+		    S9xDisplayString (GFX.InfoString, (uint8 *)screen->pixels + 100+480*2*150, 1920);
+//  		SDL_UnlockSurface(screen);
+		if (ffc < 5) {
+		  //		        SDL_UpdateRect(screen,0,0,0,0);
+			++ffc;
+		} else
+		  //		        SDL_UpdateRect(screen,64,0,512,480);
+		SDL_Flip(screen);
+			
+	  }else{
 		if (Width > 256) {
 			for (register uint32 i = 0; i < Height; i++) {
 				register uint32 *dp32 = (uint32 *)(screen->pixels) + ((i + cl) * xs) + lp;
@@ -644,6 +905,7 @@
 				}
 			}
 		}
+	  
 		if (Settings.DisplayFrameRate)
 		    S9xDisplayFrameRate ((uint8 *)screen->pixels + 128, 2560);
 		if (GFX.InfoString)
@@ -653,8 +915,13 @@
 			SDL_UpdateRect(screen,0,0,0,0);
 			++ffc;
 		} else
-			SDL_UpdateRect(screen,64,0,512,480);
+			SDL_UpdateRect(screen,64,400,50,80);
+		SDL_Flip(screen);
+	  }
+
 	} else {
+
+	  
 		if (Settings.SupportHiRes) {
 			if (Width > 256) {
 				for (register uint32 i = 0; i < Height; i++) {
@@ -674,17 +941,18 @@
 				}
 			}
 		}
+		
 		if (Settings.DisplayFrameRate)
 		    S9xDisplayFrameRate ((uint8 *)screen->pixels + 64, 640);
 		if (GFX.InfoString)
 		    S9xDisplayString (GFX.InfoString, (uint8 *)screen->pixels + 64, 640);
 //  		SDL_UnlockSurface(screen);
 		if (ffc < 5) {
-			SDL_UpdateRect(screen,0,0,0,0);
+		  SDL_UpdateRect(screen,0,0,0,0);
 			++ffc;
 		} else
-			SDL_UpdateRect(screen,32,0,256,Height);
-		//	SDL_Flip(screen);
+		  SDL_UpdateRect(screen,32,0,256,Height);
+		SDL_Flip(screen);
 	}
 	return(TRUE);
 }
@@ -900,7 +1168,7 @@
 		switch(event.type) {
 		case SDL_KEYDOWN:
 			keyssnes = SDL_GetKeyState(NULL);
-
+			
 			if (event.key.keysym.sym == sfc_key[QUIT])
 				S9xExit();
 
@@ -930,8 +1198,16 @@
 			}
 			break;
 		case SDL_KEYUP:
-			keyssnes = SDL_GetKeyState(NULL);
+		        keyssnes = SDL_GetKeyState(NULL);
+			break;
+		case SDL_JOYAXISMOTION:
+		case SDL_JOYBUTTONDOWN:
+		case SDL_JOYBUTTONUP:
+		        joystick_update(event);
+		        break;
+		  
 		}
+
 		if (keyssnes[sfc_key[ACCEL]] == SDL_PRESSED) {
 			if (!TURBO) {
 				TURBO = TRUE;
@@ -945,6 +1221,7 @@
 			}
 		}
 	}
+
 }
 
 static long log2 (long num)
diff -Nur snes9x-org/unzip/unzipP.h snes9x-sdljoy/unzip/unzipP.h
--- snes9x-org/unzip/unzipP.h	1970-01-01 09:00:00.000000000 +0900
+++ snes9x-sdljoy/unzip/unzipP.h	2003-10-27 09:42:40.000000000 +0900
@@ -0,0 +1,124 @@
+#ifndef _UNZIPP_H_
+#define _UNZIPP_H_
+
+#include "unzip.h"
+
+#ifndef local
+#define local static
+#endif
+/* compile with -Dlocal if your debugger can't find static symbols */
+
+
+
+#if !defined(unix) && !defined(CASESENSITIVITYDEFAULT_YES) && \
+                      !defined(CASESENSITIVITYDEFAULT_NO)
+#define CASESENSITIVITYDEFAULT_NO
+#endif
+
+
+#ifndef UNZ_BUFSIZE
+#define UNZ_BUFSIZE (16384)
+#endif
+
+#ifndef UNZ_MAXFILENAMEINZIP
+#define UNZ_MAXFILENAMEINZIP (256)
+#endif
+
+#ifndef ALLOC
+#define ALLOC(size) (malloc(size))
+#endif
+#ifndef TRYFREE
+#define TRYFREE(p) {if (p) free(p);}
+#endif
+
+#define SIZECENTRALDIRITEM (0x2e)
+#define SIZEZIPLOCALHEADER (0x1e)
+
+
+/* I've found an old Unix (a SunOS 4.1.3_U1) without all SEEK_* defined.... */
+
+#ifndef SEEK_CUR
+#define SEEK_CUR    1
+#endif
+
+#ifndef SEEK_END
+#define SEEK_END    2
+#endif
+
+#ifndef SEEK_SET
+#define SEEK_SET    0
+#endif
+
+/* unz_file_info_interntal contain internal info about a file in zipfile */
+typedef struct unz_file_info_internal_s
+{
+    uLong           offset_curfile;	/* relative offset of local header 4
+					 * bytes */
+}               unz_file_info_internal;
+
+
+/*
+ * file_in_zip_read_info_s contain internal information about a file in
+ * zipfile, when reading and decompress it
+ */
+typedef struct
+{
+    char           *read_buffer;/* internal buffer for compressed data */
+    z_stream        stream;	/* zLib stream structure for inflate */
+
+    uLong           pos_in_zipfile;	/* position in byte on the zipfile,
+					 * for fseek */
+    uLong           stream_initialised;	/* flag set if stream structure is
+					 * initialised */
+
+    uLong           offset_local_extrafield;	/* offset of the local extra
+						 * field */
+    uInt            size_local_extrafield;	/* size of the local extra
+						 * field */
+    uLong           pos_local_extrafield;	/* position in the local
+						 * extra field in read */
+
+    uLong           crc32;	/* crc32 of all data uncompressed */
+    uLong           crc32_wait;	/* crc32 we must obtain after decompress all */
+    uLong           rest_read_compressed;	/* number of byte to be
+						 * decompressed */
+    uLong           rest_read_uncompressed;	/* number of byte to be
+						 * obtained after decomp */
+    FILE           *file;	/* io structore of the zipfile */
+    uLong           compression_method;	/* compression method (0==store) */
+    uLong           byte_before_the_zipfile;	/* byte before the zipfile,
+						 * (>0 for sfx) */
+}               file_in_zip_read_info_s;
+
+
+/*
+ * unz_s contain internal information about the zipfile
+ */
+typedef struct
+{
+    FILE           *file;	/* io structore of the zipfile */
+    unz_global_info gi;		/* public global information */
+    uLong           byte_before_the_zipfile;	/* byte before the zipfile,
+						 * (>0 for sfx) */
+    uLong           num_file;	/* number of the current file in the zipfile */
+    uLong           pos_in_central_dir;	/* pos of the current file in the
+					 * central dir */
+    uLong           current_file_ok;	/* flag about the usability of the
+					 * current file */
+    uLong           central_pos;/* position of the beginning of the central
+				 * dir */
+
+    uLong           size_central_dir;	/* size of the central directory  */
+    uLong           offset_central_dir;	/* offset of start of central
+					 * directory with respect to the
+					 * starting disk number */
+
+    unz_file_info   cur_file_info;	/* public info about the current file
+					 * in zip */
+    unz_file_info_internal cur_file_info_internal;	/* private info about it */
+    file_in_zip_read_info_s *pfile_in_zip_read;	/* structure about the
+						 * current file if we are
+						 * decompressing it */
+}               unz_s;
+
+#endif
diff -Nur snes9x-org/unzip/unzipp.h snes9x-sdljoy/unzip/unzipp.h
--- snes9x-org/unzip/unzipp.h	2003-10-27 09:42:40.000000000 +0900
+++ snes9x-sdljoy/unzip/unzipp.h	1970-01-01 09:00:00.000000000 +0900
@@ -1,124 +0,0 @@
-#ifndef _UNZIPP_H_
-#define _UNZIPP_H_
-
-#include "unzip.h"
-
-#ifndef local
-#define local static
-#endif
-/* compile with -Dlocal if your debugger can't find static symbols */
-
-
-
-#if !defined(unix) && !defined(CASESENSITIVITYDEFAULT_YES) && \
-                      !defined(CASESENSITIVITYDEFAULT_NO)
-#define CASESENSITIVITYDEFAULT_NO
-#endif
-
-
-#ifndef UNZ_BUFSIZE
-#define UNZ_BUFSIZE (16384)
-#endif
-
-#ifndef UNZ_MAXFILENAMEINZIP
-#define UNZ_MAXFILENAMEINZIP (256)
-#endif
-
-#ifndef ALLOC
-#define ALLOC(size) (malloc(size))
-#endif
-#ifndef TRYFREE
-#define TRYFREE(p) {if (p) free(p);}
-#endif
-
-#define SIZECENTRALDIRITEM (0x2e)
-#define SIZEZIPLOCALHEADER (0x1e)
-
-
-/* I've found an old Unix (a SunOS 4.1.3_U1) without all SEEK_* defined.... */
-
-#ifndef SEEK_CUR
-#define SEEK_CUR    1
-#endif
-
-#ifndef SEEK_END
-#define SEEK_END    2
-#endif
-
-#ifndef SEEK_SET
-#define SEEK_SET    0
-#endif
-
-/* unz_file_info_interntal contain internal info about a file in zipfile */
-typedef struct unz_file_info_internal_s
-{
-    uLong           offset_curfile;	/* relative offset of local header 4
-					 * bytes */
-}               unz_file_info_internal;
-
-
-/*
- * file_in_zip_read_info_s contain internal information about a file in
- * zipfile, when reading and decompress it
- */
-typedef struct
-{
-    char           *read_buffer;/* internal buffer for compressed data */
-    z_stream        stream;	/* zLib stream structure for inflate */
-
-    uLong           pos_in_zipfile;	/* position in byte on the zipfile,
-					 * for fseek */
-    uLong           stream_initialised;	/* flag set if stream structure is
-					 * initialised */
-
-    uLong           offset_local_extrafield;	/* offset of the local extra
-						 * field */
-    uInt            size_local_extrafield;	/* size of the local extra
-						 * field */
-    uLong           pos_local_extrafield;	/* position in the local
-						 * extra field in read */
-
-    uLong           crc32;	/* crc32 of all data uncompressed */
-    uLong           crc32_wait;	/* crc32 we must obtain after decompress all */
-    uLong           rest_read_compressed;	/* number of byte to be
-						 * decompressed */
-    uLong           rest_read_uncompressed;	/* number of byte to be
-						 * obtained after decomp */
-    FILE           *file;	/* io structore of the zipfile */
-    uLong           compression_method;	/* compression method (0==store) */
-    uLong           byte_before_the_zipfile;	/* byte before the zipfile,
-						 * (>0 for sfx) */
-}               file_in_zip_read_info_s;
-
-
-/*
- * unz_s contain internal information about the zipfile
- */
-typedef struct
-{
-    FILE           *file;	/* io structore of the zipfile */
-    unz_global_info gi;		/* public global information */
-    uLong           byte_before_the_zipfile;	/* byte before the zipfile,
-						 * (>0 for sfx) */
-    uLong           num_file;	/* number of the current file in the zipfile */
-    uLong           pos_in_central_dir;	/* pos of the current file in the
-					 * central dir */
-    uLong           current_file_ok;	/* flag about the usability of the
-					 * current file */
-    uLong           central_pos;/* position of the beginning of the central
-				 * dir */
-
-    uLong           size_central_dir;	/* size of the central directory  */
-    uLong           offset_central_dir;	/* offset of start of central
-					 * directory with respect to the
-					 * starting disk number */
-
-    unz_file_info   cur_file_info;	/* public info about the current file
-					 * in zip */
-    unz_file_info_internal cur_file_info_internal;	/* private info about it */
-    file_in_zip_read_info_s *pfile_in_zip_read;	/* structure about the
-						 * current file if we are
-						 * decompressing it */
-}               unz_s;
-
-#endif
